# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = [
    'address',
    'http_proxy',
    'token',
]

__config__ = pulumi.Config('wavefront')

address = __config__.get('address') or _utilities.get_env('WAVEFRONT_ADDRESS')

http_proxy = __config__.get('httpProxy')

token = __config__.get('token') or _utilities.get_env('WAVEFRONT_TOKEN')

