# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "additional_information": "additionalInformation",
    "additional_tags": "additionalTags",
    "alert_type": "alertType",
    "api_key": "apiKey",
    "app_filter_regex": "appFilterRegex",
    "app_filter_regexes": "appFilterRegexes",
    "bucket_name": "bucketName",
    "can_modifies": "canModifies",
    "can_views": "canViews",
    "category_filters": "categoryFilters",
    "client_id": "clientId",
    "client_secret": "clientSecret",
    "content_type": "contentType",
    "controller_name": "controllerName",
    "custom_headers": "customHeaders",
    "dashboard_json": "dashboardJson",
    "display_expression": "displayExpression",
    "display_query_parameters": "displayQueryParameters",
    "display_section_table_of_contents": "displaySectionTableOfContents",
    "email_subject": "emailSubject",
    "enable_app_infra_metrics": "enableAppInfraMetrics",
    "enable_backend_metrics": "enableBackendMetrics",
    "enable_business_trx_metrics": "enableBusinessTrxMetrics",
    "enable_error_metrics": "enableErrorMetrics",
    "enable_individual_node_metrics": "enableIndividualNodeMetrics",
    "enable_overall_perf_metrics": "enableOverallPerfMetrics",
    "enable_rollup": "enableRollup",
    "enable_service_endpoint_metrics": "enableServiceEndpointMetrics",
    "encrypted_password": "encryptedPassword",
    "end_time_in_seconds": "endTimeInSeconds",
    "event_filter_type": "eventFilterType",
    "external_id": "externalId",
    "filter_rule": "filterRule",
    "force_save": "forceSave",
    "host_filter_regex": "hostFilterRegex",
    "host_tag_group_host_names_group_anded": "hostTagGroupHostNamesGroupAnded",
    "hostname_tags": "hostnameTags",
    "http_proxy": "httpProxy",
    "ingestion_policy": "ingestionPolicy",
    "instance_selection_tags": "instanceSelectionTags",
    "is_html_content": "isHtmlContent",
    "is_log_integration": "isLogIntegration",
    "json_key": "jsonKey",
    "metric_filter_regex": "metricFilterRegex",
    "metric_filters": "metricFilters",
    "notification_resend_frequency_minutes": "notificationResendFrequencyMinutes",
    "parameter_details": "parameterDetails",
    "point_tag_filter_regex": "pointTagFilterRegex",
    "point_tag_filter_regexes": "pointTagFilterRegexes",
    "project_id": "projectId",
    "relevant_customer_tags": "relevantCustomerTags",
    "relevant_host_names": "relevantHostNames",
    "relevant_host_tags": "relevantHostTags",
    "relevant_host_tags_anded": "relevantHostTagsAnded",
    "resolve_after_minutes": "resolveAfterMinutes",
    "resource_group_filters": "resourceGroupFilters",
    "role_arn": "roleArn",
    "service_refresh_rate_in_minutes": "serviceRefreshRateInMinutes",
    "source_filter_regex": "sourceFilterRegex",
    "start_time_in_seconds": "startTimeInSeconds",
    "target_id": "targetId",
    "threshold_targets": "thresholdTargets",
    "user_groups": "userGroups",
    "user_name": "userName",
    "volume_selection_tags": "volumeSelectionTags",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "additionalInformation": "additional_information",
    "additionalTags": "additional_tags",
    "alertType": "alert_type",
    "apiKey": "api_key",
    "appFilterRegex": "app_filter_regex",
    "appFilterRegexes": "app_filter_regexes",
    "bucketName": "bucket_name",
    "canModifies": "can_modifies",
    "canViews": "can_views",
    "categoryFilters": "category_filters",
    "clientId": "client_id",
    "clientSecret": "client_secret",
    "contentType": "content_type",
    "controllerName": "controller_name",
    "customHeaders": "custom_headers",
    "dashboardJson": "dashboard_json",
    "displayExpression": "display_expression",
    "displayQueryParameters": "display_query_parameters",
    "displaySectionTableOfContents": "display_section_table_of_contents",
    "emailSubject": "email_subject",
    "enableAppInfraMetrics": "enable_app_infra_metrics",
    "enableBackendMetrics": "enable_backend_metrics",
    "enableBusinessTrxMetrics": "enable_business_trx_metrics",
    "enableErrorMetrics": "enable_error_metrics",
    "enableIndividualNodeMetrics": "enable_individual_node_metrics",
    "enableOverallPerfMetrics": "enable_overall_perf_metrics",
    "enableRollup": "enable_rollup",
    "enableServiceEndpointMetrics": "enable_service_endpoint_metrics",
    "encryptedPassword": "encrypted_password",
    "endTimeInSeconds": "end_time_in_seconds",
    "eventFilterType": "event_filter_type",
    "externalId": "external_id",
    "filterRule": "filter_rule",
    "forceSave": "force_save",
    "hostFilterRegex": "host_filter_regex",
    "hostTagGroupHostNamesGroupAnded": "host_tag_group_host_names_group_anded",
    "hostnameTags": "hostname_tags",
    "httpProxy": "http_proxy",
    "ingestionPolicy": "ingestion_policy",
    "instanceSelectionTags": "instance_selection_tags",
    "isHtmlContent": "is_html_content",
    "isLogIntegration": "is_log_integration",
    "jsonKey": "json_key",
    "metricFilterRegex": "metric_filter_regex",
    "metricFilters": "metric_filters",
    "notificationResendFrequencyMinutes": "notification_resend_frequency_minutes",
    "parameterDetails": "parameter_details",
    "pointTagFilterRegex": "point_tag_filter_regex",
    "pointTagFilterRegexes": "point_tag_filter_regexes",
    "projectId": "project_id",
    "relevantCustomerTags": "relevant_customer_tags",
    "relevantHostNames": "relevant_host_names",
    "relevantHostTags": "relevant_host_tags",
    "relevantHostTagsAnded": "relevant_host_tags_anded",
    "resolveAfterMinutes": "resolve_after_minutes",
    "resourceGroupFilters": "resource_group_filters",
    "roleArn": "role_arn",
    "serviceRefreshRateInMinutes": "service_refresh_rate_in_minutes",
    "sourceFilterRegex": "source_filter_regex",
    "startTimeInSeconds": "start_time_in_seconds",
    "targetId": "target_id",
    "thresholdTargets": "threshold_targets",
    "userGroups": "user_groups",
    "userName": "user_name",
    "volumeSelectionTags": "volume_selection_tags",
}
